@@ -1,5 +1,5 @@
 
-from cmd_menu_framework.Path import Path
+from cmdMenuFramework.Path import Path
 
 class Context:
     
